#
# spec file for package gstreamer-devtools
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   gst-devtools

%{?sle15_python_module_pythons}
Name:           gstreamer-devtools
Version:        1.24.12
Release:        1.1
Summary:        Development and debugging tools for GStreamer
License:        LGPL-2.1-or-later
Group:          Productivity/Multimedia/Other
URL:            https://gstreamer.freedesktop.org
Source:         %{url}/src/%{_name}/%{_name}-%{version}.tar.xz
# PATCH-FIX-UPSTREAM gst-devtools-fix-hicolor-dir.patch -- Install icon file in correct folder
Patch0:         gst-devtools-fix-hicolor-dir.patch

BuildRequires:  fdupes
BuildRequires:  meson >= 1.1
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-3.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(gstreamer-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0) >= %{version}
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0) >= %{version}
%if 0%{?suse_version} >= 1500
BuildRequires:  pkgconfig(gstreamer-rtsp-server-1.0) >= %{version}
%endif
BuildRequires:  pkgconfig(gstreamer-transcoder-1.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.0.0
BuildRequires:  pkgconfig(json-glib-1.0)
Obsoletes:      gstreamer-validate < 1.18.1
Provides:       gstreamer-validate = %{version}

%description
Development and debugging tools for GStreamer

GstValidate detects when elements are not behaving as expected and
report it to the user so he knows how things are supposed to work
inside a GstPipeline. In the end, fixing issues found by the tool will
ensure that all elements behave all together in the expected way.

The easiest way of using GstValidate is to use one of its command-line
tools, located at tools/ directory. It is also possible to monitor
GstPipelines from any application by using the LD_PRELOAD gstvalidate
lib. The third way of using it is to write your own application that
links and uses libgstvalidate.

%package -n libgstvalidate-1_0-0
Summary:        GStreamer pipeline validator
# all the nice validator scripts live in the main package
Group:          System/Libraries

%description -n libgstvalidate-1_0-0
GstValidate detects when elements are not behaving as expected and
report it to the user so he knows how things are supposed to work
inside a GstPipeline. In the end, fixing issues found by the tool will
ensure that all elements behave all together in the expected way.

%package -n typelib-1_0-GstValidate-1_0
Summary:        GObject introspection bindings for the GStreamer pipeline validator
Group:          System/Libraries

%description -n typelib-1_0-GstValidate-1_0
GstValidate detects when elements are not behaving as expected and
report it to the user so he knows how things are supposed to work
inside a GstPipeline. In the end, fixing issues found by the tool will
ensure that all elements behave all together in the expected way.

%package devel
Summary:        Header files for the GStreamer development and debugging tools
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libgstvalidate-1_0-0 = %{version}
Requires:       typelib-1_0-GstValidate-1_0 = %{version}
Obsoletes:      gstreamer-validate-devel < 1.18.0
Provides:       gstreamer-validate-devel = %{version}

%description devel
GstValidate detects when elements are not behaving as expected and
report it to the user so he knows how things are supposed to work
inside a GstPipeline. In the end, fixing issues found by the tool will
ensure that all elements behave all together in the expected way.

%prep
%autosetup -n %{_name}-%{version} -p1
sed -i -e '1{s,^#!/usr/bin/env python3,#!%{_bindir}/python3,}' validate/tools/gst-validate-launcher.in
sed -i -e '1{s,^#!/usr/bin/env python3,#!%{_bindir}/python3,}' debug-viewer/gst-debug-viewer

%build
%meson \
	-Ddebug_viewer=enabled \
	-Ddoc=disabled \
	%{nil}
%meson_build

%install
%meson_install
%fdupes -s %{buildroot}/%{_prefix}
%ldconfig_scriptlets -n libgstvalidate-1_0-0

%files
%license validate/COPYING
%doc ChangeLog validate/README
%{_bindir}/gst-validate-1.0
%{_bindir}/gst-validate-images-check-1.0
%{_bindir}/gst-validate-launcher
%{_bindir}/gst-validate-media-check-1.0
%if 0%{?suse_version} >= 1500
%{_bindir}/gst-validate-rtsp-server-1.0
%endif
%{_bindir}/gst-validate-transcoding-1.0
%{_libdir}/gst-validate-launcher/
%dir %{_datadir}/gstreamer-1.0/
%{_datadir}/gstreamer-1.0/validate/
%dir %{_libdir}/gstreamer-1.0/
%dir %{_libdir}/gstreamer-1.0/validate/

%{_bindir}/gst-debug-viewer
%{python_sitelib}/GstDebugViewer/
%{_datadir}/applications/org.freedesktop.GstDebugViewer.desktop
%{_datadir}/gst-debug-viewer/
%{_datadir}/icons/hicolor/*/apps/gst-debug-viewer.png
%{_datadir}/icons/hicolor/scalable/apps/gst-debug-viewer.svg
%{_datadir}/metainfo/org.freedesktop.GstDebugViewer.appdata.xml

%files -n libgstvalidate-1_0-0
%{_libdir}/libgstvalidate-1.0.so.*
%{_libdir}/libgstvalidate-default-overrides-1.0.so.*

%files -n typelib-1_0-GstValidate-1_0
%{_libdir}/girepository-1.0/GstValidate-1.0.typelib

%files devel
%{_datadir}/gir-1.0/GstValidate-1.0.gir
%{_includedir}/gstreamer-1.0/
%{_libdir}/gstreamer-1.0/libgstvalidatetracer.so
%{_libdir}/gstreamer-1.0/validate/libgstvalidatefaultinjection.so
%{_libdir}/gstreamer-1.0/validate/libgstvalidategapplication.so
%{_libdir}/gstreamer-1.0/validate/libgstvalidategtk.so
%{_libdir}/gstreamer-1.0/validate/libgstvalidatessim.so
%{_libdir}/pkgconfig/gstreamer-validate-1.0.pc
%{_libdir}/libgstvalidate-1.0.so
%{_libdir}/libgstvalidate-default-overrides-1.0.so

%changelog
* Mon Feb  3 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.12:
  + No changes, stable version bump only
* Tue Jan  7 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.11:
  + No changes, stable version bump only
* Mon Dec  9 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.10:
  + validate: Fix leaks in ssim components.
* Tue Nov  5 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.9:
  + validate:
  - Ignore flaky dash playbin3 issue
  - Blacklist more netsim tests
* Mon Sep 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.8:
  + pad-monitor: Fix remaining pad function data handling
  + pad-monitor: Fix pad function data properly
* Fri Aug 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.7:
  + validate: Fix copying of action name.
* Wed Aug 14 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.6:
  + Highlighted bugfixes:
  - Fix compatibility with FFmpeg 7.0.
  - qmlglsink: Fix failure to display content on recent Android
    devices.
  - adaptivedemux: Fix handling of closed caption streams.
  - cuda: Fix runtime compiler loading with old CUDA tookit.
  - decodebin3 stream selection handling fixes.
  - d3d11compositor, d3d12compositor: Fix transparent background
    mode with YUV output.
  - d3d12converter: Make gamma remap work as intended.
  - h264decoder: Update output frame duration for interlaced
    video when second field frame is discarded.
  - macOS audio device provider now listens to audio devices
    being added/removed at runtime.
  - Rust plugins: audioloudnorm, s3hlssink, gtk4paintablesink,
    livesync and webrtcsink fixes.
  - videoaggregator: preserve features in non-alpha caps for
    subclasses with non-system memory sink caps.
  - vtenc: Fix redistribute latency spam.
  - v4l2: fixes for complex video formats.
  - va: Fix strides when importing DMABUFs, dmabuf handle leaks,
    and blocklist unmaintained Intel i965 driver for encoding.
  - waylandsink: Fix surface cropping for rotated streams.
  - webrtcdsp: Enable multi_channel processing to fix handling of
    stereo streams.
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements.
* Fri Jun 28 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.24.5:
  + Highlighted bugfixes:
  - webrtcsink: Support for AV1 via nvav1enc, av1enc or rav1enc
    encoders
  - AV1 RTP payloader/depayloader fixes to work correctly with
    Chrome and Pion WebRTC
  - av1parse, av1dec error handling/robustness improvements
  - av1enc: Handle force-keyunit events properly for WebRTC
  - decodebin3: selection and collection handling improvements
  - hlsdemux2: Various fixes for discontinuities, variant
    switching, playlist updates
  - qml6glsink: fix RGB format support
  - rtspsrc: more control URL handling fixes
  - v4l2src: Interpret V4L2 report of sync loss as video signal
    loss
  - d3d12 encoder, memory and videosink fixes
  - vtdec: more robust error handling, fix regression
  - ndi: support for NDI SDK v6
  - Various bug fixes, memory leak fixes, and other stability and
    reliability improvements
- Please see https://gstreamer.freedesktop.org/releases/1.24/ for
  changes between 1.24.0 and this version and even more in-depth
  info.
* Wed Mar  6 2024 Antonio Larrosa <alarrosa@suse.com>
- Add missing file in package
* Tue Mar  5 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.24.0:
  * In action types, add a way to avoid checking property value
    after setting it, in case elements do it async for example.
  * Add a vmethod to free GstValidateActionParameters to be more
    binding friendly.
  * Allow scenarios to define the pipeline state target in the
    metadata instead of assuming PLAYING state.
  * Add support to run sub-pipelines/scenarios
  * Added support to forward buffers from appsink to appsrc
  * Add a way to set pipeline base-time, start-time and force
    using the system clock.
  * Add a 'fill-mode' to the appsrc-push action type so we can
    create some type of streams easily using an appsrc, giving
    control when writing scenarios without requiring files with
    the content.
  * Add a "select-streams" action type to test "stream aware"
    elements.
  * Add a way to wait for a property to reach a specified value
    before executing an action. For example it is possible to wait
    for a pad to get some specific caps set before executing an
    action.
  * validate: Add support to replace variables in deeply nested
    structures in particular for more complex action types where
    some of the properties are inside structures.
  * Fixed compatibility with Python 3.12.
  * For more detailed information on this update, please see
    https://gstreamer.freedesktop.org/releases/1.24/
- Use %%{?sle15_python_module_pythons}
- Remove patch reduce-required-meson.patch since meson 1.1 is
  really required now.
* Thu Feb  1 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.9:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Thu Jan  4 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.8:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Wed Nov 15 2023 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.22.7:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Fri Sep 22 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.6:
  + No changes, stable bump only.
- Rebase reduce-required-meson.patch.
* Tue Jul 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.5:
  + No changes
- Rebase reduce-required-meson.patch.
* Mon Jun 26 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.4:
  + No changes.
- Rebase reduce-required-meson.patch.
* Wed May 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.3:
  + No changes, version bump only.
- Rebase reduce-required-meson.patch.
* Wed Apr 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.2:
  + No changes, version bump only.
- Rebase patches.
* Thu Mar  9 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.1:
  + Fix gstreamer-validate-1.0 dependency name
  + tests:
  - Fix known issue definition location for unit tests and how we
    handle them in validate launcher
  - Mark elements_srtp.test_play test as flaky
  + validate: Fix gst_validate_execute_action annotation
  + validate-scenario:
  - Fix g-i warning in annotation
  - Sink refs when building
- Rebase patch with quilt.
* Wed Mar  1 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to reduce the required meson version to 0.61.0 since
  that's what we have in SLE 15:
  * reduce-required-meson.patch
* Wed Jan 25 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.22.0:
  + Please see changes in gstreamer main package, major version
    bump.
* Fri Dec 23 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.5:
  + No major changes.
* Sat Oct 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.4:
  + No changes.
* Wed Jun 22 2022 Aaron Stern <ukbeast89@protonmail.com>
- Update to version 1.20.3:
  + No upstream changes available.
* Mon May  9 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.1:
  + meson: provide gobject-cast-checks, glib-checks and
    glib-asserts options at top level as well
* Fri Mar 18 2022 Antonio Larrosa <alarrosa@suse.com>
- Update to version 1.20.1:
  + gst-env: various clean-ups and documentation improvements
* Wed Feb  9 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.20.0:
  + No upstream changes available.
- Add pkgconfig(gstreamer-transcoder-1.0) BuildRequires: New
  dependency.
* Fri Feb  4 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.6:
  + No changes, version bump only.
* Tue Jan 25 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unused hotdoc BuildRequires, and pass doc=disabled to meson,
  we were not building docs in any case, and we have a new seperate
  gstreamer-docs package that have all the documentation.
- Drop cmake BuildRequires, neither used, nor needed.
- Add conditional pkgconfig(gstreamer-rtsp-server-1.0)
  BuildRequires, build optional validate-rtsp support for
  Tumbleweed and newer.
- Add fdupes BuildRequires and macro, remove duplicate files.
- Use ldconfig_scriptlets macro for post(un) handling.
- Add gst-devtools-fix-hicolor-dir.patch, install icon file in
  correct folder.
- Drop _service, use upstream url for tarball.
- Use yet a sed call to fix a shebang.
* Sun Oct 17 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Pass debug_viewer=enabled to meson, build the optional
  gst-debug-viewer app.
* Wed Sep 15 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.5:
  + scenario: Fix EOS handling in seek_forward.scenario
  + validate-utils: Only modify structure fields that really need
    updates
  + Don't use volatile to mean atomic (fixes compiler warnings with
    gcc 11)
- Changes from version 1.18.4:
  + No changes
* Sat Jan 16 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.3:
  + No changes
* Thu Jan  7 2021 Bjørn Lie <bjorn.lie@gmail.com>
- Drop unneeded and unwanted gstreamer-devtools recommends from
  libgstvalidate-1_0-0 subpackage.
- Cleanup spec file.
* Thu Dec 10 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.18.2:
  + No changes.
- Tweak _service file.
* Wed Oct 28 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.18.1:
  + Highlighted bugfixes in 1.18.1
  - important security fixes
  - bug fixes and memory leak fixes
  - various stability and reliability improvements
* Tue Oct 27 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Also provide/obsolete gstreamer-validate-devel.
* Mon Sep 14 2020 Antonio Larrosa <alarrosa@suse.com>
- Rename package gstreamer-validate to gstreamer-devtools to follow
  upstream
- Update to 1.18.0:
  + Highlights:
  - GstTranscoder: new high level API for applications to
    transcode media files from one format to another
  - High Dynamic Range (HDR) video information representation
    and signalling enhancements
  - Instant playback rate change support
  - Active Format Description (AFD) and Bar Data support
  - RTSP server and client implementations gained ONVIF trick
    modes support
  - Hardware-accelerated video decoding on Windows via
    DXVA2/Direct3D11
  - Microsoft Media Foundation plugin for video capture and
    hardware-accelerated video encoding on Windows
  - qmlgloverlay: New overlay element that renders a QtQuick
    scene over the top of an input video stream
  - imagesequencesrc: New element to easily create a video
    stream from a sequence of jpeg or png images
  - dashsink: New sink to produce DASH content
  - dvbsubenc: New DVB Subtitle encoder element
  - MPEG-TS muxing now also supports TV broadcast compliant
    muxing with constant bitrate muxing and SCTE-35 support
  - rtmp2: New RTMP client source and sink element from-scratch
    implementation
  - svthevcenc: New SVT-HEVC-based H.265 video encoder
  - vaapioverlay: New compositor element using VA-API
  - rtpmanager gained support for Google's Transport-Wide
    Congestion Control (twcc) RTP extension
  - splitmuxsink and splitmuxsrc gained support for auxiliary
    video streams
  - webrtcbin now contains some initial support for
    renegotiation involving stream addition and removal
  - RTP support was enhanced with new RTP source and sink
    elements to easily set up RTP streaming via rtp:// URIs
  - avtp: New Audio Video Transport Protocol (AVTP) plugin for
    Time-Sensitive Applications
  - Support for the Video Services Forum's Reliable Internet
    Stream Transport (RIST) TR-06-1 Simple Profile
  - Universal Windows Platform (UWP) support
  - rpicamsrc: New element for capturing from the Raspberry Pi
    camera
  - RTSP Server TCP interleaved backpressure handling
    improvements as well as support for Scale/Speed headers
  - GStreamer Editing Services gained support for nested
    timelines, per-clip speed rate control and the OpenTimelineIO
    format.
  - Autotools build system has been removed in favour of Meson
* Wed Dec  4 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.2:
  + No changes, version bump only
* Tue Sep 24 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.16.1:
  + See main gstreamer package for changelog.
* Fri Jun 28 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary. Drop em dashes from summaries.
* Sun Jun 16 2019 mgorse@suse.com
- Update to version 1.16.0:
  + Highlights
  - GStreamer WebRTC stack gained support for data channels for
    peer-to-peer communication based on SCTP, BUNDLE support, as
    well as support for multiple TURN servers.
  - AV1 video codec support for Matroska and QuickTime/MP4
    containers and more configuration options and supported
    input formats for the AOMedia AV1 encoder
  - Support for Closed Captions and other Ancillary Data in video
  - Support for planar (non-interleaved) raw audio
  - GstVideoAggregator, compositor and OpenGL mixer elements are
    now in -base
  - New alternate fields interlace mode where each buffer carries
    a single field
  - WebM and Matroska ContentEncryption support in the Matroska
    demuxer
  - new WebKit WPE-based web browser source element
  - Video4Linux: HEVC encoding and decoding, JPEG encoding, and
    improved dmabuf import/export
  - Hardware-accelerated Nvidia video decoder gained support for
    VP8/VP9 decoding, whilst the encoder gained support for
    H.265/HEVC encoding.
  - Many improvements to the Intel Media SDK based
    hardware-accelerated video decoder and encoder plugin (msdk):
    dmabuf import/export for zero-copy integration with other
    components; VP9 decoding; 10-bit HEVC encoding; video
    post-processing (vpp) support including deinterlacing; and
    the video decoder now handles dynamic resolution changes.
  - The ASS/SSA subtitle overlay renderer can now handle multiple
    subtitles that overlap in time and will show them on screen
    simultaneously
  - The Meson build is now feature-complete (*) and it is now the
    recommended build system on all platforms. The Autotools
    build is scheduled to be removed in the next cycle.
  - The GStreamer Rust bindings and Rust plugins module are now
    officially part of upstream GStreamer.
  - The GStreamer Editing Services gained a gesdemux element that
    allows directly playing back serialized edit list with
    playbin or (uri)decodebin
  - Many performance improvements
- Add libgstvalidateflow.so to files.
* Fri May 31 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 1.14.5:
  + No changes provided upstream.
* Wed Oct  3 2018 bjorn.lie@gmail.com
- Update to version 1.14.4:
  + Bugfix release, please see .changes in gstreamer main package.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 1.14.3:
  + Bugfix release, please see .changes in gstreamer main package.
* Tue Jul 24 2018 bjorn.lie@gmail.com
- Update to version 1.14.2:
  + launcher:
  - Allow retrieving coredumps from within flatpak.
  - Fix the --forever switch.
  + Update all gitignore.
* Sun May 20 2018 bjorn.lie@gmail.com
- Update to version 1.14.1:
  + GstPad: Fix race condition causing the same probe to be called
    multiple times
  + Fix occasional deadlocks on windows when outputting debug
    logging
  + Fix debug levels being applied in the wrong order
  + GIR annotation fixes for bindings
  + audiomixer, audioaggregator: fix some negotiation issues
  + gst-play-1.0: fix leaving stdin in non-blocking mode after exit
  + flvmux: wait for caps on all input pads before writing header
    even if source is live
  + flvmux: don't wake up the muxer unless there is data, fixes
    busy looping if there's no input data
  + flvmux: fix major leak of input buffers
  + rtspsrc, rtsp-server: revert to RTSP RFC handling of
    sendonly/recvonly attributes
  + rtpvrawpay: fix payloading with very large mtu sizes where
    everything fits into a single RTP packet
  + v4l2: Fix hard-coded enabled v4l2 probe on Linux/ARM
  + v4l2: Disable DMABuf for emulated formats when using libv4l2
  + v4l2: Always set colorimetry in S_FMT
  + asfdemux: Set stream-format field for H264 streams and handle
    H.264 in bytestream format
  + x265enc: Fix tagging of keyframes on output buffers
  + ladspa: Fix critical during plugin load on Windows
  + decklink: Fix COM initialisation on Windows
  + h264parse: fix re-use across pipeline stop/restart
  + mpegtsmux: fix force-keyframe event handling and PCR/PMT
    changes that would confuse some players with generated HLS
    streams
  + adaptivedemux: Support period change in live playlist
  + rfbsrc: Fix support for applevncserver and support NULL pool in
    decide_allocation
  + jpegparse: Fix APP1 marker segment parsing
  + h265parse: Make caps writable before modifying them, fixes
    criticals
  + fakevideosink: request an extra buffer if enable-last-sample is
    enabled
  + wasapisrc: Don't provide a clock based on WASAPI's clock
  + wasapi: Only use audioclient3 when low-latency, as it might
    otherwise glitch with slow CPUs or VMs
  + wasapi: Don't derive device period from latency time, should
    make it more robust against glitches
  + audiolatency: Fix wave detection in buffers and avoid bogus pts
    values while starting
  + msdk: fix plugin load on implementations with only HW support
  + msdk: dec: set framerate to the driver only if provided, not in
    0/1 case
  + msdk: Don't set extended coding options for JPEG encode
  + rtponviftimestamp: fix state change function init/reset causing
    races/crashes on shutdown
  + decklink: fix initialization failure in windows binary
  + ladspa: Fix critical warnings during plugin load on Windows and
    fix dependencies in meson build
  + gl: fix cross-compilation error with viv-fb
  + qmlglsink: make work with eglfs_kms
  + rtspclientsink: Don't deadlock in preroll on early close
  + rtspclientsink: Fix client ports for the RTCP backchannel
  + rtsp-server: Fix session timeout when streaming data to client
    over TCP
  + vaapiencode: h264: find best profile in those available, fixing
    negotiation errors
  + vaapi: remove custom GstGL context handling, use GstGL instead.
    Fixes GL Context sharing with WebkitGtk on wayland
  + gst-editing-services: various fixes
  + gst-python: bump pygobject req to 3.8;
    fix GstPad.set_query_function(); dist autogen.sh and
    configure.ac in tarball
  + g-i: pick up GstVideo-1.0.gir from local build directory in
    GstGL build
  + g-i: update constant values for bindings
  + avoid duplicate symbols in plugins across modules in static
    builds
  + ... and many, many more!
* Wed Apr 25 2018 bjorn.lie@gmail.com
- Update to version 1.14.0:
  + Highlights:
  - WebRTC support: real-time audio/video streaming to and from
    web browsers;
  - Experimental support for the next-gen royalty-free AV1 video
    codec
  - Video4Linux: encoding support, stable element names and
    faster device probing;
  - Support for the Secure Reliable Transport (SRT) video
    streaming protocol;
  - RTP Forward Error Correction (FEC) support (ULPFEC);
  - RTSP 2.0 support in rtspsrc and gst-rtsp-server;
  - ONVIF audio backchannel support in gst-rtsp-server and
    rtspsrc;
  - playbin3 gapless playback and pre-buffering support;
  - Tee, our stream splitter/duplication element, now does
    allocation query aggregation which is important for efficient
    data handling and zero-copy;
  - QuickTime muxer has a new prefill recording mode that allows
    file import in Adobe Premiere and FinalCut Pro while the file
    is still being written;
  - rtpjitterbuffer fast-start mode and timestamp offset
    adjustment smoothing;
  - souphttpsrc connection sharing, which allows for connection
    reuse, cookie sharing, etc;
  - nvdec: new plugin for hardware-accelerated video decoding
    using the NVIDIA NVDEC API;
  - Adaptive DASH trick play support;
  - ipcpipeline: new plugin that allows splitting a pipeline
    across multiple processes;
  - Major gobject-introspection annotation improvements for large
    parts of the library API;
  - GStreamer C# bindings have been revived and seen many updates
    and fixes;
  - The externally maintained GStreamer Rust bindings had many
    usability improvements and cover most of the API now.
    Coinciding with the 1.14 release, a new release with the 1.14
    API additions is happening.
  + Updated translations.
* Fri Mar 30 2018 bjorn.lie@gmail.com
- Update to version 1.12.5:
  + Various bugfixes.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Dec 11 2017 zaitor@opensuse.org
- Update to version 1.12.4:
  + No changes, stable version bump only.
* Wed Dec  6 2017 dimstar@opensuse.org
- Drop pkgconfig(libgee-1.0) BuildRequires: the build system makes
  no reference to libgee anymore.
* Mon Sep 18 2017 zaitor@opensuse.org
- Update to version 1.12.3:
  + launcher: Automatically disable output coloration if not
    supported.
  + meson: Fix the way we set the testsuite version.
  + validate:launcher: Use the number of failed test as exit code.
* Fri Jul 14 2017 zaitor@opensuse.org
- Update to version 1.12.2:
  + Bugs fixed: bgo#764025.
* Wed Jun 21 2017 zaitor@opensuse.org
- Update to version 1.12.1:
  + validate: Target the 1.12 integration testsuite.
  + Fixup version in meson.build.
* Wed May 10 2017 zaitor@opensuse.org
- Update to version 1.12.0:
  + launcher: Allow using the base launcher as a test manager.
  + tools: Fix dotfile name.
- Changes from version 1.11.91:
  + Bugs fixed: bgo#781213.
- Changes from version 1.11.90:
  + Misc fixes.
* Sat Feb 25 2017 zaitor@opensuse.org
- Update to version 1.11.2:
  + Bugs fixed: bgo#778279, bgo#777938, bgo#777977.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.11.1:
  + Bugs fixed: bgo#773898.
- Drop pkgconfig(gstreamer-video-1.0) BuildRequires following
  upstream changes.
* Thu Feb 23 2017 zaitor@opensuse.org
- Update to version 1.10.4:
  + Testsuite fixes.
* Mon Jan 30 2017 zaitor@opensuse.org
- Update to version 1.10.3:
  + Bugs fixed: bgo#776280.
* Sat Dec  3 2016 zaitor@opensuse.org
- Update to version 1.10.2:
  + Minor bugfixes.
* Sun Nov 27 2016 zaitor@opensuse.org
- Update to version 1.10.1:
  + Meson update.
- Changes from version 1.10.0:
  + Bugs fixed: bgo#772439, bgo#772543.
- Add pkgconfig(json-glib-1.0) BuildRequires: New dependency.
* Wed Aug 24 2016 zaitor@opensuse.org
- Update to version 1.8.3 (boo#996937):
  + Fix Validate plugin paths mixup.
  + No execute ON_ADDITION if a previous action is executed
    playback_time.
- Drop gstreamer-validate-correctplugindir.patch: Fixed upstream.
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 1.8.2:
  + configure: Properly set the current validate testsuite to 1.8.
  + validate: Stop using deprecated method.
* Mon Jun 13 2016 novell@mirell.de
- Add gstreamer-validate-correctplugindir.patch from upstream
  to fix Pitivi startup on some systems.
* Thu Apr 21 2016 zaitor@opensuse.org
- Update to version 1.8.1:
  + bgo#764192: gst-validate build error on Mac OS X due to missing
    linking to GIO.
* Sat Mar 26 2016 zaitor@opensuse.org
- Update to version 1.8.0:
  + Hardware-accelerated zero-copy video decoding on Android
  + New video capture source for Android using the
    android.hardware.Camera API.
  + Windows Media reverse playback support (ASF/WMV/WMA).
  + New tracing system provides support for more sophisticated
    debugging tools.
  + New high-level GstPlayer playback convenience API.
  + Initial support for the new Vulkan API, see Matthew Waters'
    blog post for more details.
  + Improved Opus audio codec support: Support for more than two
    channels; MPEG-TS demuxer/muxer can now handle Opus;
    sample-accurate encoding/decoding/transmuxing with Ogg,
    Matroska, ISOBMFF (Quicktime/MP4), and MPEG-TS as container;
    new codec utility functions for Opus header and caps handling
    in pbutils library. The Opus encoder/decoder elements were
    also moved to gst-plugins-base (from -bad), and the opus RTP
    depayloader/payloader to -good.
  + GStreamer VAAPI module now released and maintained as part of
    the GStreamer project.
  + Asset proxy support in the GStreamer Editing Services.
- Add explicit pkgconfig(gee-1.0) BuildRequires following upstreams
  configure.
- Replace gobject-introspection-devel for
  pkgconfig(gobject-introspection-1.0) BuildRequires.
* Thu Nov 26 2015 dimstar@opensuse.org
- Initial package, version 1.6.0.
